// -*- mode: rjsx; -*-

// React Todo List Application
//   from https://www.digitalocean.com/community/tutorials/how-to-build-a-react-to-do-app-with-react-hooks
//   By Kapehe Jorgenson
//   Updated September 17, 2020

/**************************************************************************************************/

// Instead of importing React
const { Component, render, useState } = wp.element;

import './App.scss';

/**************************************************************************************************/

function Todo({ todo, index, complete_todo, remove_todo }) {
    return (
        <div
            className="todo"
            style={{ textDecoration: todo.is_completed ? "line-through" : "" }}
        >
            {todo.text}
            <div>
                <button onClick={() => complete_todo(index)}>Complete</button>
                <button onClick={() => remove_todo(index)}>x</button>
            </div>
        </div>
    );
}

function TodoForm({ add_todo }) {
    const [value, set_value] = useState("");

    const handle_submit = e => {
        e.preventDefault();
        if (!value) return;
        add_todo(value);
        set_value("");
    };

    return (
        <form onSubmit={handle_submit}>
            <input
                type="text"
                className="input"
                placeholder="add a new todo..."
                value={value}
                onChange={e => set_value(e.target.value)}
            />
        </form>
    );
}

function App() {
    const [todos, set_todos] = useState([
        {
            text: "Learn about React",
            is_completed: false
        },
        {
            text: "Meet friend for lunch",
            is_completed: false
        },
        {
            text: "Build really cool todo app",
            is_completed: false
        }
    ]);

    const add_todo = text => {
        const new_todos = [...todos, { text }];
        set_todos(new_todos);
    };

    const complete_todo = index => {
        const new_todos = [...todos];
        new_todos[index].is_completed = true;
        set_todos(new_todos);
    };

    const remove_todo = index => {
        const new_todos = [...todos];
        new_todos.splice(index, 1);
        set_todos(new_todos);
    };

    return (
        <div className="react-example">
            <div className="todo-list">
                {todos.map((todo, index) => (
                    <Todo
                        key={index}
                        index={index}
                        todo={todo}
                        complete_todo={complete_todo}
                        remove_todo={remove_todo}
                    />
                ))}
                <TodoForm add_todo={add_todo} />
            </div>
        </div>
    );
}

/**************************************************************************************************/

// Application is wrapped in <div id='app'></div>
const wrapper = document.getElementById('app');
if (wrapper)
    // instead of ReactDOM.render()
    render(<App />, wrapper);
else
    console.log('Element id=app not found in the dom');
